# 予期しないエラー

予期しないエラーが発生しました。バグレポートを送信しますか? バグレポートは自動的に行われ、将来的に同様のエラーが起きないように役立てられます。

[エラーメッセージを送信する](opensesame://event.bug_report_send){: .important-button}

プライバシー:

- エラーメッセージ(下に示されています) はユーザー名などの識別情報を含む場合があります。 その場合、この情報はバグを修正する以外の目的には使用されません。

詳細情報:

- 使用OS: %(platform)s
- OpenSesame: %(version)s
- Python: %(python_version)s

このメッセージを非表示にしたい場合:

- 今後バグレポートメッセージを非表示にしたい場合には、メニュー → ツール → プラグインと拡張機能マネージャー からバグレポートを無効にすることができます。無効にすることで問題は自動的に解決はしません--あくまでバグレポートが非表示になるだけです。

エラーメッセージ:

%(traceback)s
